@@ -1,3 +1,4 @@
+#%%
 import os
 import requests
 import json
@@ -5,7 +6,6 @@ import json
 user_id = os.environ['USER_ID']
 token = os.environ['API_TOKEN']
 url_api = os.environ['VERIFY_ENDPOINT']
-url_api = 'https://reczg13drk.execute-api.eu-west-1.amazonaws.com/prod/user/project/task/verify'
 headers = {'x-api-key': f"{token}"}
 
 def get_errors_fails(report_path: str):
@@ -36,8 +36,9 @@ def get_errors_fails(report_path: str):
 
 def mark_complete(task_id: str, message=None):
     data = {
-            'task_id': task_id,
-            'user_id': user_id,
+            'taskId': task_id,
+            'userId': user_id,
+            'verified': True
             }
     if message:
         data['message'] = message
@@ -47,13 +48,15 @@ def mark_complete(task_id: str, message=None):
 
 def mark_incomplete(task_id: str, message=None):
     data = {
-            'task_id': task_id,
-            'user_id': user_id,
-            'complete': False
+            'taskId': task_id,
+            'userId': user_id,
+            'verified': False
             }
     if message:
         data['message'] = message
 
     r = requests.post(url_api, headers=headers, data=json.dumps(data))
 
-    assert r.status_code == 200
\ No newline at end of file
+    assert r.status_code == 200
+
+#%%
\ No newline at end of file
